@@ -9,7 +9,7 @@ use warnings;
 use Error::Pure qw(err);
 
 # Version.
-our $VERSION = 0.03;
+our $VERSION = 0.04;
 
 # Flush.
 sub flush {
@@ -331,15 +331,26 @@ __END__
 
 =head1 DEPENDENCIES
 
-L<Error::Pure>.
+L<Error::Pure>,
+L<Tags::Output>.
 
 =head1 SEE ALSO
 
-L<Tags>,
-L<Tags::Output>,
-L<Tags::Output::Indent>,
-L<Tags::Output::PYX>,
-L<Tags::Output::Raw>.
+=over
+
+=item L<Tags>
+
+Structure oriented SGML/XML/HTML/etc. elements manipulation.
+
+=item L<Tags::Output>
+
+Base class for Tags::Output::*.
+
+=item L<Task::Tags>
+
+Install the Tags modules.
+
+=back
 
 =head1 AUTHOR
 
@@ -354,6 +365,6 @@ L<http://skim.cz>
 
 =head1 VERSION
 
-0.03
+0.04
 
 =cut
